@@ -62,12 +62,13 @@ public class PreferencesActivator implements BundleActivator {
 
     private ServiceRegistration userConfigFlagRegistration;
 
-    public void start(BundleContext context) throws Exception {
+    public void start(final BundleContext context) throws Exception {
         userConfigFlagRegistration = context.registerService(PreferencesItemService.class.getName(), new Enabled(), null);
     }
 
-    public void stop(BundleContext context) throws Exception {
+    public void stop(final BundleContext context) throws Exception {
         userConfigFlagRegistration.unregister();
+        userConfigFlagRegistration = null;
     }
 
 }
